@@ -2,10 +2,16 @@ import json
 
 from django.forms import widgets
 from django.utils.safestring import mark_safe
-from wagtail.core.telepath import register
-from wagtail.core.widget_adapters import WidgetAdapter
+from wagtail import VERSION as WAGTAIL_VERSION
 from wagtail.utils.widgets import WidgetWithScript
 
+if WAGTAIL_VERSION >= (3, 0):
+    from wagtail.telepath import register
+    from wagtail.widget_adapters import WidgetAdapter
+else:
+    from wagtail.core.telepath import register
+    from wagtail.core.widget_adapters import WidgetAdapter
+
 
 class PolyfillColorInputWidget(widgets.TextInput):
     class Media:
